@@ -225,12 +225,12 @@ def keyboardByLinkText(value, *keys, index=0, **parDict):
     item.send_keys(*keys)
 
 
-def keyboardClearByCss(value, index=0, **parDict):
+def clearByCss(value, index=0, **parDict):
     item = getByCss(value, index=index, **parDict)[0]
     item.clear()
 
 
-def keyboardClearByLinkText(value, index=0, **parDict):
+def clearByLinkText(value, index=0, **parDict):
     item = getByLinkText(value, index=index, **parDict)[0]
     item.clear()
 
@@ -260,9 +260,9 @@ def setRequestsRuleDisabled():
 
 def clearRequestsRule():
     _checkIsWire()
-    setRequestsRule()
+    setRequestsRule([])
 
 
-def clearRequests(rule):
+def clearRequests():
     _checkIsWire()
     del driver.requests
